﻿using System;
using System.Linq.Expressions;

namespace RO.Vema.Helper.BusinessObject.Services
{
    public static class FlexReflector
    {
        public static string GetPropertyName<T>(Expression<Func<T>> expression)
        {
            if (expression.Body.NodeType == ExpressionType.MemberAccess)
            {
                return ((MemberExpression) expression.Body).Member.Name;
            }

            if (expression.Body.NodeType == ExpressionType.Convert)
            {
                UnaryExpression unaryExpression = (UnaryExpression) expression.Body;
                if (unaryExpression.Operand.NodeType == ExpressionType.MemberAccess)
                {
                    return ((MemberExpression) unaryExpression.Operand).Member.Name;
                }
            }

            throw new NotSupportedException("This overload accepts only member access lambda expressions");
        }

        public static string GetPropertyName<TItem, TResult>(Expression<Func<TItem, TResult>> expression)
        {
            if (expression.Body.NodeType == ExpressionType.MemberAccess)
            {
                return ((MemberExpression) expression.Body).Member.Name;
            }

            if (expression.Body.NodeType == ExpressionType.Convert)
            {
                UnaryExpression unaryExpression = (UnaryExpression) expression.Body;
                if (unaryExpression.Operand.NodeType == ExpressionType.MemberAccess)
                {
                    return ((MemberExpression) unaryExpression.Operand).Member.Name;
                }
            }

            throw new NotSupportedException("This overload accepts only member access lambda expressions");
        }
    }

    public static class FlexReflectorExtensions
    {
        public static string GetPropertyName<T>(this T instance, Expression<Func<T, object>> propertyAccesor)
        {
            return FlexReflector.GetPropertyName(propertyAccesor);
        }
    }
}