// <copyright file="NumericDataBindingHelper.cs" company="VEMA Calcul Electronic">
//   Copyright VEMA Calcul Electronic. All rights reserved.
// </copyright>
// <created>
//   <date value="2009.11.18" />
//   <author name="Emanuel Haisiuc" />
// </created>

using System;
using System.Windows.Forms;
using Infragistics.Win.UltraWinEditors;

namespace RO.Vema.Helper.Client.DataBinding
{
    /// <summary>
    /// Helper pentru evenimentele Format si Parse in controlul UltraNumericEditor.
    /// </summary>
    public static class NumericDataBindingHelper
    {
		/// <summary>
        /// Event handler pentru Parse intr-un control UltraNumericEditor cu care se editeaza un decimal.
        /// </summary>
        /// <param name="sender">the sender</param>
        /// <param name="e">the event args</param>
        public static void OnDecimalNumericDataBindingParse(object sender, ConvertEventArgs e)
		{
		    Binding binding = sender as Binding;

		    if (binding == null)
		    {
		        return;
		    }

		    UltraNumericEditor numericEditor = binding.Control as UltraNumericEditor;

		    if (numericEditor == null)
		    {
		        return;
		    }

		    if (e.DesiredType == typeof(decimal))
		    {
		        if (e.Value is string)
		        {
		            string value = (string) e.Value;
		            e.Value = ControlHelper.GetDecimal(value, numericEditor.PromptChar);
		        }
		        else if (e.Value == DBNull.Value)
		        {
		            e.Value = decimal.Zero;
		        }
		    }
		}

        /// <summary>
        /// Event handler pentru Format intr-un control UltraNumericEditor cu care se editeaza un decimal.
        /// </summary>
        /// <param name="sender">the sender</param>
        /// <param name="e">the event args</param>
        public static void OnDecimalNumericDataBindingFormat(object sender, ConvertEventArgs e)
        {
            if (e.Value is decimal && e.DesiredType == typeof(string))
            {
                decimal value = (decimal) e.Value;
                e.Value = (value != decimal.Zero) ? value.ToString() : string.Empty;
            }
        }

        /// <summary>
        /// Event handler pentru Format intr-un control UltraNumericEditor cu care se editeaza un decimal.
        /// </summary>
        /// <param name="sender">the sender</param>
        /// <param name="e">the event args</param>
        public static void OnDecimalNumericWith2DecimalPlacesDataBindingFormat(object sender, ConvertEventArgs e)
        {
            if (e.Value is decimal && e.DesiredType == typeof(string))
            {
                decimal value = (decimal) e.Value;
                e.Value = (value != decimal.Zero) ? value.ToString("0.00") : string.Empty;
            }
        }

        /// <summary>
        /// Event handler pentru Format intr-un control UltraNumericEditor cu care se editeaza un decimal.
        /// </summary>
        /// <param name="sender">the sender</param>
        /// <param name="e">the event args</param>
        public static void OnDecimalNumericWith2DecimalPlacesAllowZeroDataBindingFormat(object sender, ConvertEventArgs e)
        {
            if (e.Value is decimal && e.DesiredType == typeof(string))
            {
                decimal value = (decimal) e.Value;
				e.Value = value.ToString("0.00");
            }
        }

        /// <summary>
        /// Event handler pentru Parse intr-un control UltraNumericEditor cu care se editeaza un decimal.
        /// </summary>
        /// <param name="sender">the sender</param>
        /// <param name="e">the event args</param>
        public static void OnIntegerNumericDataBindingParse(object sender, ConvertEventArgs e)
        {
            Binding binding = sender as Binding;

            if (binding == null)
            {
                return;
            }

            UltraNumericEditor numericEditor = binding.Control as UltraNumericEditor;

            if (numericEditor == null)
            {
                return;
            }

            if (e.DesiredType == typeof(int))
            {
                if (e.Value is string)
                {
                    string value = (string) e.Value;
                    e.Value = ControlHelper.GetInteger(value, numericEditor.PromptChar);
                }
                else if (e.Value == DBNull.Value)
                {
                    e.Value = 0;
                }
            }
        }

        /// <summary>
        /// Event handler pentru Format intr-un control UltraNumericEditor cu care se editeaza un decimal.
        /// </summary>
        /// <param name="sender">the sender</param>
        /// <param name="e">the event args</param>
        public static void OnIntegerNumericDataBindingFormat(object sender, ConvertEventArgs e)
        {
            if (e.Value is int && e.DesiredType == typeof(string))
            {
                int value = (int) e.Value;
                e.Value = (value != 0) ? value.ToString() : string.Empty;
            }
        }
    }
}