﻿// <copyright file="MainView.cs" company="VEMA Calcul Electronic">
//   Copyright VEMA Calcul Electronic. All rights reserved.
// </copyright>
// <created>
//   <date value="2013.02.04" />
//   <author name="Emanuel Haisiuc" />
// </created>

using System;
using System.Collections.Generic;
using System.Windows.Forms;
using RO.Vema.ProduseShowroom.DataAccess.Interop;
using RO.Vema.ProduseShowroom.Entities;

namespace RO.Vema.ProduseShowroom
{
    public partial class MainView : Form
    {
        private ProdusInShowroomViewLinear _viewLinear;
        private ProdusInShowroomViewDefault _viewDefault;
        private DateTime _startTimeChildFormShow;

        public MainView()
        {
            InitializeComponent();
        }

        public void AddMessage(string message)
        {
            lstMesaje.SelectedIndex = lstMesaje.Items.Add(message);
        }

        public void DisplayTotalTimeTookToShow(DateTime endTime)
        {
            AddMessage(
                string.Format(
                    "Showing the child form took a total of {0} ms",
                    endTime.Subtract(_startTimeChildFormShow).TotalMilliseconds));
        }

        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

            btnShowDefault.Click += OnShowDefaultClick;
            btnShowLinear.Click += OnShowLinearClick;

            DateTime time1 = DateTime.Now;

            List<Produs> listProduse = ProduseReader.ListProduse;

            DateTime time2 = DateTime.Now;

            AddMessage(
                string.Format(
                    "Reading {0} records took {1} ms", listProduse.Count, time2.Subtract(time1).TotalMilliseconds));


            InstantiateLinear(listProduse);
            InstantiateDefault(listProduse);
        }

        private void InstantiateLinear(List<Produs> listProduse)
        {
            AddMessage("----------------- Instantiating the child view with combos' DropDownSearchMethod set to Linear ------------------");
            
            DateTime time1 = DateTime.Now;

            _viewLinear = new ProdusInShowroomViewLinear(this);

            DateTime time2 = DateTime.Now;

            AddMessage(
                string.Format("Instantiating the child form took: {0} ms", time2.Subtract(time1).TotalMilliseconds));

            _viewLinear.Produse = listProduse;

            DateTime time3 = DateTime.Now;

            AddMessage(
                string.Format(
                    "Setting the DataSource for product binding source took {0} ms",
                    time3.Subtract(time2).TotalMilliseconds));

            AddMessage("------------------------------ End instantiating Linear ---------------------------------------------------------");
        }

        private void InstantiateDefault(List<Produs> listProduse)
        {
            AddMessage("----------------- Instantiating the child view with combos' DropDownSearchMethod set to Default ------------------");
            
            DateTime time1 = DateTime.Now;

            _viewDefault = new ProdusInShowroomViewDefault(this);

            DateTime time2 = DateTime.Now;

            AddMessage(
                string.Format("Instantiating the child form took: {0} ms", time2.Subtract(time1).TotalMilliseconds));

            _viewDefault.Produse = listProduse;

            DateTime time3 = DateTime.Now;

            AddMessage(
                string.Format(
                    "Setting the DataSource for product binding source took {0} ms",
                    time3.Subtract(time2).TotalMilliseconds));

            AddMessage("------------------------------ End instantiating Default ---------------------------------------------------------");
        }

        private void OnShowDefaultClick(object sender, EventArgs e)
        {
            AddMessage("--------------- Showing Default child form ----------------------------");

            _startTimeChildFormShow = DateTime.Now;

            ProdusInShowroom produsInShowroom = new ProdusInShowroom();
            produsInShowroom.DataMontarii = DateTime.Today;
            produsInShowroom.CodCorpIluminat = 301318;
            produsInShowroom.CodBec = 12150227;
            _viewDefault.ProdusInShowroom = produsInShowroom;

            DateTime time2 = DateTime.Now;

            AddMessage(string.Format("Setting the ProductInShowroom DataSource to the editing entity took {0}", time2.Subtract(_startTimeChildFormShow).TotalMilliseconds));

            _viewDefault.ShowDialog();
        
            AddMessage("--------------- End Showing Default child form ----------------------------");
        }

        private void OnShowLinearClick(object sender, EventArgs e)
        {
            AddMessage("--------------- Showing Linear child form ----------------------------");

            _startTimeChildFormShow = DateTime.Now;

            ProdusInShowroom produsInShowroom = new ProdusInShowroom();
            produsInShowroom.DataMontarii = DateTime.Today;
            produsInShowroom.CodCorpIluminat = 301318;
            produsInShowroom.CodBec = 12150227;
            _viewLinear.ProdusInShowroom = produsInShowroom;

            DateTime time2 = DateTime.Now;

            AddMessage(string.Format("Setting the ProductInShowroom DataSource to the editing entity took {0}", time2.Subtract(_startTimeChildFormShow).TotalMilliseconds));

            _viewLinear.ShowDialog();

            AddMessage("--------------- End Showing Linear child form ----------------------------");
        }
    }
}
